@@ -3,6 +3,7 @@ Logit <- function(expression, inst = NULL){
          term = function(predLabels, ...) {
              paste("log((", predLabels, ")/(1 - (", predLabels, ")))", sep = "")
          },
-         call = as.expression(match.call()))
+         call = as.expression(match.call()),
+         match = 1)
 }
 class(Logit) <- "nonlin"
