@@ -1,4 +1,4 @@
 coef.gnm <- function(object, ...) {
     structure(object$coefficients, ofInterest = object$ofInterest,
-              class = "coef.gnm")
+              class = c("coef.gnm", "numeric"))
 }
