@@ -15,10 +15,7 @@ noRelationship <- gnm(.counts ~ pain, eliminate = .rowID,
                       family = "poisson", data = backPain)
 
 oneDimensional <- update(noRelationship,
-                         ~ . + Mult(pain - 1, x1 + x2 + x3 - 1))
+                         ~ . + Mult(pain, x1 + x2 + x3))
 
 print(oneDimensional$deviance, digits=10)
 print(oneDimensional$df)
-
-
-
